==============
enhydris-cache
==============


.. image:: https://img.shields.io/pypi/v/enhydris-cache.svg
        :target: https://pypi.python.org/pypi/enhydris-cache

.. image:: https://img.shields.io/travis/openmeteo/enhydris-cache.svg
        :target: https://travis-ci.org/openmeteo/enhydris-cache

.. image:: https://codecov.io/github/openmeteo/enhydris-cache/coverage.svg
        :target: https://codecov.io/gh/openmeteo/enhydris-cache
        :alt: Coverage

.. image:: https://pyup.io/repos/github/openmeteo/enhydris-cache/shield.svg
         :target: https://pyup.io/repos/github/openmeteo/enhydris-cache/
         :alt: Updates

Utilities for spatial integration of time series.


* Free software: GNU General Public License v3
* Documentation: https://enhydris-cache.readthedocs.io.
